# trina_extension

## A python package to indentify the type of a given file

---

# Use the package in your project

### Install the package

```
pip install trina-extension
```

### Using the package

```
import trina_extension.extension as extension

extension.type("test.py")
```

---

Trina Mukherjee © 2023

> **Note**
> This is for a university project. Might not be maintained in future.
